==> mingw-w64-partio-1.17.1-1.src.tar.zst: partio-1.17.1/src/tests/testcache.cpp <==
/*
PARTIO SOFTWARE
Copyright 2010 Disney Enterprises, Inc. All rights reserved

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

* Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.

* Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in
the documentation and/or other materials provided with the
distribution.

* The names "Disney", "Walt Disney Pictures", "Walt Disney Animation
Studios" or the names of its contributors may NOT be used to
endorse or promote products derived from this software without
specific prior written permission from Walt Disney Pictures.

Disclaimer: THIS SOFTWARE IS PROVIDED BY WALT DISNEY PICTURES AND
CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
FOR A PARTICULAR PURPOSE, NONINFRINGEMENT AND TITLE ARE DISCLAIMED.
IN NO EVENT SHALL WALT DISNEY PICTURES, THE COPYRIGHT HOLDER OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND BASED ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*/
#include <Partio.h>
#include <cassert>
#include <iostream>

int main(int argc,char* argv[])
{
    Partio::ParticlesDataMutable* p=Partio::create();
    Partio::ParticleAttribute attr=p->addAttribute("position",Partio::VECTOR,3);
    p->addParticle();
    float* pos=p->dataWrite<float>(attr,0);
    pos[0]=1;pos[1]=2;pos[2]=3;
    Partio::write("/tmp/test.bgeo",*p);
    p->release();

    Partio::ParticlesInfo* p1=Partio::readCached("/tmp/test.bgeo",false);
    Partio::ParticlesInfo* p2=Partio::readCached("/tmp/test.bgeo",false);
    assert(p1==p2);
    p1->release();p2->release();
    Partio::ParticlesInfo* p3=Partio::readCached("/tmp/test.bgeo",false);
    p3->release();
    //assert(p2!=p3);

    return 0;
}

==> mingw-w64-partio-1.19.0-1.src.tar.zst: partio-1.19.0/src/tests/testcache.cpp <==
/*
PARTIO SOFTWARE
Copyright 2010 Disney Enterprises, Inc. All rights reserved

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

* Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.

* Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in
the documentation and/or other materials provided with the
distribution.

* The names "Disney", "Walt Disney Pictures", "Walt Disney Animation
Studios" or the names of its contributors may NOT be used to
endorse or promote products derived from this software without
specific prior written permission from Walt Disney Pictures.

Disclaimer: THIS SOFTWARE IS PROVIDED BY WALT DISNEY PICTURES AND
CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
FOR A PARTICULAR PURPOSE, NONINFRINGEMENT AND TITLE ARE DISCLAIMED.
IN NO EVENT SHALL WALT DISNEY PICTURES, THE COPYRIGHT HOLDER OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND BASED ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*/
#include <Partio.h>
#include <cassert>
#include <iostream>

int main(int argc,char* argv[])
{
    Partio::ParticlesDataMutable* p=Partio::create();
    Partio::ParticleAttribute attr=p->addAttribute("position",Partio::VECTOR,3);
    p->addParticle();
    float* pos=p->dataWrite<float>(attr,0);
    pos[0]=1;pos[1]=2;pos[2]=3;
    Partio::write("test.bgeo",*p);
    p->release();

    Partio::ParticlesInfo* p1=Partio::readCached("test.bgeo",false);
    Partio::ParticlesInfo* p2=Partio::readCached("test.bgeo",false);
    assert(p1==p2);
    p1->release();p2->release();
    Partio::ParticlesInfo* p3=Partio::readCached("test.bgeo",false);
    p3->release();
    //assert(p2!=p3);

    return 0;
}
